from setuptools import setup

setup(name='dn_db_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['dn_db_distributions'],
      autor = 'Andres Viana',
      autor_email = 'andres.viana.viana@gmail.com',
    zip_safe=False)
